@@ -2,8 +2,8 @@
 """
 :Author: HuangJingCan
 :Date: 2020-06-02 11:08:39
-:LastEditTime: 2021-04-15 14:59:41
-:LastEditors: HuangJingCan
+@LastEditTime: 2022-02-18 12:00:03
+@LastEditors: HuangJianYi
 :description: App相关
 """
 from seven_cloudapp.handlers.seven_base import *
@@ -123,4 +123,48 @@ class BaseInfoHandler(SevenBaseHandler):
         if base_info:
             return self.reponse_json_success(data)
 
-        return self.reponse_json_error("BaseInfoError", "基础信息出错")
\ No newline at end of file
+        return self.reponse_json_error("BaseInfoError", "基础信息出错")
+
+
+class CheckGmPowerHandler(SevenBaseHandler):
+    """
+    :description: 校验是否有GM工具权限
+    """
+    def get_async(self):
+        """
+        :description: 校验是否有GM工具权限
+        :param 
+        :return: True是 False否
+        :last_editors: HuangJianYi
+        """
+        is_power = False
+        store_user_nick = self.get_taobao_param().user_nick.split(':')[0]
+        if not store_user_nick:
+            return self.reponse_json_success(is_power)
+        if store_user_nick == config.get_value("test_user_nick"):
+            is_power = True
+        return self.reponse_json_success(is_power)
+
+
+class GetAppidByGmHandler(SevenBaseHandler):
+    """
+    :description: 获取应用标识
+    """
+    @filter_check_params("store_name")
+    def get_async(self):
+        """
+        :description: 获取应用标识
+        :param store_name:店铺名称
+        :return app_id
+        :last_editors: HuangJianYi
+        """
+        app_id = ""
+        store_name = self.get_param("store_name")
+        store_user_nick = self.get_taobao_param().user_nick.split(':')[0]
+        if not store_user_nick:
+            return self.reponse_json_success(app_id)
+        if store_user_nick == config.get_value("test_user_nick"):
+            app_info_dict = AppInfoModel(context=self).get_dict("store_name=%s", field="app_id", params=[store_name])
+            if app_info_dict:
+                app_id = app_info_dict["app_id"]
+        return self.reponse_json_success(app_id)
