@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-06-02 11:08:39
-@LastEditTime: 2022-02-16 19:02:35
+@LastEditTime: 2022-03-02 15:22:14
 @LastEditors: HuangJianYi
 :description: 订单相关
 """
@@ -303,7 +303,7 @@ class PrizeOrderExportHandler(SevenBaseHandler):
                     prize_roster_list_filter = [prize_roster for prize_roster in prize_roster_list if prize_roster["prize_order_id"] == prize_order["id"]]
                     for prize_roster in prize_roster_list_filter:
                         data_row = {}
-                        data_row["淘宝主订单号"] = prize_order["order_no"]
+                        data_row["淘宝主订单号"] = prize_roster["main_pay_order_no"]
                         data_row["淘宝子订单号"] = prize_roster["order_no"]
                         data_row["小程序订单号"] = prize_order["order_no"]
                         data_row["淘宝名"] = prize_order["user_nick"]
