@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2022-02-24 17:25:13
+@LastEditTime: 2022-03-01 17:03:02
 @LastEditors: HuangJianYi
 :Description: 潮玩盲盒基础路由
 """
@@ -158,6 +158,7 @@ def seven_cloudapp_ppmt_route():
 
         #2.4
         (r"/client/get_crm_integral", user.GetCrmIntegralHandler),
+        (r"/client/get_is_member", user.GetIsMemberHandler),
         (r"/client/crm_integral_gear_list", act.CrmIntegralGearlListHandler),
-        (r"/client/get_high_power_list", power.GetHighPowerListHandler),
+        (r"/client/get_high_power_list", power.GetHighPowerListHandler)
     ]
\ No newline at end of file
